plone_inline_editing
open | /portal |
verifyText | parent-fieldname-title | Welcome to Plone
clickAt | parent-fieldname-title |
waitForEditable | title |
type | title | Welcome to Plone in Sorrento
keyPress | title | \13
pause | 8000 |
waitForElementPresent | parent-fieldname-title |
assertText | parent-fieldname-title | Welcome to Plone in Sorrento
open | /portal |
verifyText | parent-fieldname-title | Welcome to Plone in Sorrento
clickAt | parent-fieldname-title |
waitForEditable | title |
type | title | Welcome, stranger. It's been a long journey
keyPress | title | \27
pause | 8000 |
waitForElementPresent | parent-fieldname-title |
assertText | parent-fieldname-title | Welcome to Plone in Sorrento